pub struct MergeBurnMsg {
pub collection_id: u32,
pub token_id: u32,
}Expand description
Message that is used for the tokens that will be burned.
Fields
collection_id: u32token_id: u32Trait Implementations
Sourceimpl Clone for MergeBurnMsg
impl Clone for MergeBurnMsg
Sourcefn clone(&self) -> MergeBurnMsg
fn clone(&self) -> MergeBurnMsg
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MergeBurnMsg
impl Debug for MergeBurnMsg
Sourceimpl<'de> Deserialize<'de> for MergeBurnMsg
impl<'de> Deserialize<'de> for MergeBurnMsg
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MergeBurnMsg
impl JsonSchema for MergeBurnMsg
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MergeBurnMsg
impl PartialEq for MergeBurnMsg
Sourcefn eq(&self, other: &MergeBurnMsg) -> bool
fn eq(&self, other: &MergeBurnMsg) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for MergeBurnMsg
impl Serialize for MergeBurnMsg
impl StructuralPartialEq for MergeBurnMsg